summaryrefslogtreecommitdiff
path: root/include/svx/svdobj.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2017-05-10 13:52:51 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2017-05-12 09:54:23 +0200
commita651dbcfca9e198b5c2561076961504586bc6bea (patch)
tree812eee16af9bc3c4c75b8b45a4c126f99ad1bab3 /include/svx/svdobj.hxx
parent9b5ce4023d35c4cc82f7b17e79b8fedbcb1367dd (diff)
convert SdrLayerId to strong_int
Also - rename SetOfByte to SdrLayerIDSet - add asserts in SdrLayerAdmin::GetUniqueLayerID so that we don't allocate overlapping SdrLayerID values - add a new constant SDRLAYERPOS_NOTFOUND to be returned from SdrLayerAdmin::GetLayerPos Change-Id: I3bb3489f9338e3d02c4040bcbd811744699941c8 Reviewed-on: https://gerrit.libreoffice.org/37467 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
Diffstat (limited to 'include/svx/svdobj.hxx')
-rw-r--r--include/svx/svdobj.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/svx/svdobj.hxx b/include/svx/svdobj.hxx
index 9f8ef8f95422..8c1e4b59d278 100644
--- a/include/svx/svdobj.hxx
+++ b/include/svx/svdobj.hxx
@@ -69,7 +69,7 @@ class SdrObjUserDataList;
class SdrObjPlusData;
class SdrGluePoint;
class SdrGluePointList;
-class SetOfByte;
+class SdrLayerIDSet;
class OutputDevice;
class Fraction;
@@ -182,7 +182,7 @@ public:
Point aPos;
Point aDownPos;
VclPtr<OutputDevice> pOut;
- const SetOfByte* pVisiLayer;
+ const SdrLayerIDSet* pVisiLayer;
const SdrPageView* pPageView;
sal_uInt16 nTol;
bool bDown;
@@ -341,8 +341,8 @@ public:
virtual SdrLayerID GetLayer() const;
virtual void NbcSetLayer(SdrLayerID nLayer);
virtual void SetLayer(SdrLayerID nLayer);
- // renaming GetLayerSet -> getMergedHierarchyLayerSet to make clear what happens here. rSet needs to be empty.
- void getMergedHierarchyLayerSet(SetOfByte& rSet) const;
+ // renaming GetSdrLayerIDSet -> getMergedHierarchySdrLayerIDSet to make clear what happens here. rSet needs to be empty.
+ void getMergedHierarchySdrLayerIDSet(SdrLayerIDSet& rSet) const;
void SendUserCall(SdrUserCallType eUserCall, const tools::Rectangle& rBoundRect) const;